import httpRequest from '@/utils/axios'
/* ------------------------------------广告------------------------------------ */
/**
 * 获取广告列表
 * @param {string} type_id 类型id
 * @param {number} id_title id或标题
 * @param {string} project_id 项目id
 */
export function getAdList(params) {
  return httpRequest.get('/api/cms/admin/v1/advertisements', { params })
}
/**
 * 创建广告
 */
export function createAd(data) {
  return httpRequest.post('/api/cms/admin/v1/advertisement/create', data)
}
/**
 * 更新广告
 * @param {string} id 广告id
 * @param {object} data 广告表单数据
 */
export function updateAd(id, data) {
  return httpRequest.put(`/api/cms/admin/v1/advertisement/${id}/update`, data)
}
/**
 * 发布广告
 * @param {string} id
 * @param {number} data.is_publish 发布1 取消发布0
 */
export function publishAd(id, data) {
  return httpRequest.post(`/api/cms/admin/v1/advertisement/${id}/publish`, data)
}
/**
 * 审核广告
 * @param {string} id
 * @param {number} data.audit_status 2通过 3驳回
 * @param {string} data.audit_remarks 审核说明
 */
export function auditAd(id, data) {
  return httpRequest.post(`/api/cms/admin/v1/advertisement/${id}/audit`, data)
}

/* ------------------------------------文章------------------------------------ */
/**
 * 获取文章列表
 * @param {string} type_id 类型id
 * @param {number} id_title id或标题
 * @param {string} project_id 项目id
 */
export function getArticleList(params) {
  return httpRequest.get('/api/cms/admin/v1/articles', { params })
}
/**
 * 创建文章
 */
export function createArticle(data) {
  return httpRequest.post('/api/cms/admin/v1/article/create', data)
}
/**
 * 发布文章
 * @param {string} id
 * @param {number} data.is_publish 发布1 取消发布0
 */
export function publishArticle(id, data) {
  return httpRequest.post(`/api/cms/admin/v1/article/${id}/publish`, data)
}

/* ------------------------------------图文------------------------------------ */
/**
 * 获取图文列表
 * @param {string} type_id 类型id
 * @param {number} id_title id或标题
 * @param {string} project_id 项目id
 */
export function getImgTextList(params) {
  return httpRequest.get('/api/cms/admin/v1/img-texts', { params })
}
/**
 * 发布图文
 * @param {string} id
 * @param {number} data.is_publish 发布1 取消发布0
 */
export function publishImgText(id, data) {
  return httpRequest.post(`/api/cms/admin/v1/img-text/${id}/publish`, data)
}
/**
 * 获取广告/文章/图文新建时所选项目对应的类型
 * @param {number} content_type 类型 1文章 2广告 3图文
 * @param {string} project_id 项目id
 */
export function getProjectContentTypeList(type, id) {
  return httpRequest.get(`/api/cms/admin/v1/type/${type}/project/${id}`)
}
